# ketter

![ketter](./assets/banner.png)

Ketter is an asynchronous http downloader written in [Python](https://python.org)

## Features

- Download many files concurrently
- Set custom HTTP headers to be used in download requests
- Resume incomplete downloads at later sessions automatically
- Beautiful progress bars that provide feedback on the ongoing download

## Installation

`pip3 install ketter`

### Update

`pip3 install --upgrade ketter`
